@@ -173,6 +173,7 @@ class VdsApiV2(VdsApiBase):
                                  lats=None, lons=None, rois=None,
                                  file_format=None,
                                  av_win=None, av_win_dir=None, masked=None, clim=None, t=None,
+                                 provide_coverage=None,
                                  log_config=False):
         """
         Generate one or more uris for the `[point/roi]-time-series` enpoints.
@@ -212,6 +213,8 @@ class VdsApiV2(VdsApiBase):
             Add climatology column calculated based on the average column
         t: int
             Calculate derived root zone as additional column with given smoothing `T` value (days)
+        provide_coverage: bool
+            Include coverage percentage in the output, roi-time-series only
         log_config: bool
             Write the used configuration to the logging file and steam
         """
@@ -230,9 +233,11 @@ class VdsApiV2(VdsApiBase):
                       start_time=start_time, end_time=end_time,
                       lats=lats, lons=lons, rois=rois, file_format=file_format,
                       av_win=av_win, av_win_dir=av_win_dir,
-                      masked=masked, clim=clim, t=t)
+                      masked=masked, clim=clim, t=t,
+                      provide_coverage=provide_coverage)
         defaults = dict(file_format='csv', av_win=0, masked=False,
                         clim=False, t=None, av_win_dir='center',
+                        provide_coverage=False,
                         lats=[], lons=[], rois=[])
         config = configure(config, defaults, config_file, self.logger)
         for key in ['lons', 'lats', 'rois', 'products']:
@@ -269,8 +274,10 @@ class VdsApiV2(VdsApiBase):
             to see the names of the settings that can be changed
         """
         if self._config is None:
-            self.logger.error('API was not configured. Choose one of the configure methods to setup the parameters')
-            return None
+            error_msg = ('API was not configured. '
+                         'Choose one of the configure methods to setup the parameters')
+            self.logger.error(error_msg)
+            raise RuntimeError(error_msg)
 
         if not add:
             self.async_requests = []
@@ -317,6 +324,8 @@ class VdsApiV2(VdsApiBase):
                                f'&climatology={json.dumps(self._config["clim"])}')
                         if self._config['t'] is not None:
                             uri += f'&exp_filter_t={self._config["t"]:d}'
+                        if loc.startswith('roi_id'):
+                            uri += f'&provide_coverage={json.dumps(self._config["provide_coverage"])}'
                         self.async_requests.append(uri)
                         self.logger.debug(f'Generated URI: {uri}')
 
@@ -440,7 +449,7 @@ class VdsApiV2(VdsApiBase):
         uri = f'http://{self.host}/api/v2/products/{product}/point-value?lat={lat}&lon={lon}&date={date}'
         return self.get_content(uri)['value']
 
-    def get_roi_df(self, product, roi, start_date, end_date):
+    def get_roi_df(self, product, roi, start_date, end_date, provide_coverage=False):
         """
         Method to querry streamed json output and transform this into
         a pandas DataFrame
@@ -455,6 +464,9 @@ class VdsApiV2(VdsApiBase):
             start date to retrieve data yyyy-mm-dd
         end_date: str
             end date to retrieve data yyyy-mm-dd (inclusive)
+        provide_coverage: Bool, optional
+            If True, the coverage parameter will be
+            included. Default is False.
 
         Returns
         -------
@@ -464,7 +476,8 @@ class VdsApiV2(VdsApiBase):
         roi_id = self.rois[roi].id
         uri = (f'https://{self.host}/api/v2/products/{product}/roi-time-series-sync?'
                f'roi_id={roi_id}&start_time={start_date}&end_time={end_date}&climatology=true&'
-               f'avg_window_direction=backward&avg_window_days=20&format=csv')
+               f'avg_window_direction=backward&provide_coverage={str(provide_coverage).lower()}'
+               f'&avg_window_days=20&format=csv')
         r = self.get(uri)
         csv = BytesIO()
         for chunk in r.iter_content(2048):
